genepop-utils: Programming utilities

set_restrictionR Documentation

Programming utilities

Description

getVersion returns the version number of the C++ code (the same number that identifies the C++ executable). set_restriction(TRUE) sets the maximum number of populations and of loci to 300.

Usage

set_restriction(set = FALSE)

getVersion()

Arguments

set

logical: whether to set restrictions on number of populations and of loci


genepop documentation built on July 9, 2026, 1:06 a.m.